@@ -21,33 +21,33 @@ def _css_escape(text: str) -> str:
 
 
 def style_for_print(options: Options) -> str:
-    scss = f"""
-    :root {{
-        string-set: author '{_css_escape(options.author)}',
-            copyright '{_css_escape(options.copyright)}',
-            title '{_css_escape(options.cover_title)}';
-    }}
-    h1, h2, h3 {{
+    scss = """
+    :root {
+        string-set: author '%s',
+            copyright '%s',
+            title '%s';
+    }
+    h1, h2, h3 {
         string-set: chapter content();
-    }}
-    """
+    }
+    """ % (
+        _css_escape(options.author),
+        _css_escape(options.copyright),
+        _css_escape(options.cover_title)
+    )
     css = sass.compile(string=scss)
 
-    output_style = 'compressed'
-    if options.debug_html:
-        output_style = 'nested'
-
     base_path = os.path.abspath(os.path.dirname(__file__))
 
     filename = os.path.join(base_path, "report-print.scss")
-    css += sass.compile(filename=filename, output_style=output_style)
+    css += sass.compile(filename=filename)
 
     if options.cover or options.back_cover:
         filename = os.path.join(base_path, "cover.scss")
-        css += sass.compile(filename=filename, output_style=output_style)
+        css += sass.compile(filename=filename)
 
     filename = os.path.join(options.custom_template_path, 'styles.scss')
     if os.path.exists(filename):
-        css += sass.compile(filename=filename, output_style=output_style)
+        css += sass.compile(filename=filename)
 
     return css
